@@ -1,24 +1,25 @@
-#!/usr/bin/env python3.10
 """
-    NAME:           Onboardme
+    NAME:           onboardme
     DESCRIPTION:    Program to take care of a bunch of onboarding tasks for new
-                    machines running macOS and/or Debian.
+                    machines running macOS and/or Debian, including:
+                      dot_files, managing packages, ide_setup, group management
     AUTHOR:         Jesse Hitch
     LICENSE:        GNU AFFERO GENERAL PUBLIC LICENSE
 """
+
 from click import option, command, Choice
-import importlib
+from importlib import import_module
+from importlib.metadata import version as get_version
 import logging
-
-# rich helps pretty print everything
-from rich.console import Console
 from rich.logging import RichHandler
-
-# custom libs
 from .help_text import RichCommand, options_help
 from .env_config import check_os_support, OS, process_configs, USR_CONFIG_FILE
 from .env_config import DEFAULTS as OPTS
 from .console_logging import print_manual_steps
+from .dot_files import setup_dot_files
+from .pkg_management import run_pkg_mngrs
+from .sudo_setup import setup_sudo
+from .firewall import configure_firewall
 
 
 HELP = options_help()
@@ -29,35 +30,44 @@ def setup_logger(level="", log_file=""):
     Sets up rich logger and stores the values for it in a db for future import
     in other files. Returns logging.getLogger("rich")
     """
+    # determine logging level
     if not level:
         if USR_CONFIG_FILE and 'log' in USR_CONFIG_FILE:
             level = USR_CONFIG_FILE['log']['level']
         else:
             level = 'warn'
 
+    log_level = getattr(logging, level.upper(), None)
+
+    # these are params to be passed into logging.basicConfig
+    opts = {'level': log_level, 'format': "%(message)s", 'datefmt': "[%X]"}
+
+    # we only log to a file if one was passed into config.yaml or the cli
     if not log_file:
         if USR_CONFIG_FILE:
             log_file = USR_CONFIG_FILE['log'].get('file', None)
 
-    log_level = getattr(logging, level.upper(), None)
-    # these are params to be passed into logging.basicConfig
-    log_opts = {'level': log_level,
-                'format': "%(message)s",
-                'datefmt': "[%X]",
-                'handlers': [RichHandler(rich_tracebacks=True)]}
-
-    if log_level == 10:
-        # log the name of the function if we're in debug mode :)
-        log_opts['format'] = "[bold]%(funcName)s()[/bold]: %(message)s"
-
-    # we only log to a file if one was passed into config.yaml or the cli
+    # rich typically handles much of this but we don't use rich with files
     if log_file:
-        log_opts['handlers'] = [RichHandler(console=Console(file=log_file),
-                                            rich_tracebacks=True)]
+        opts['filename'] = log_file
+        opts['format'] = "%(asctime)s %(levelname)s %(funcName)s: %(message)s"
+    else:
+        rich_handler_opts = {'rich_tracebacks': True}
+        # 10 is the DEBUG logging level int value
+        if log_level == 10:
+            # log the name of the function if we're in debug mode :)
+            opts['format'] = "[bold]%(funcName)s()[/bold]: %(message)s"
+            rich_handler_opts['markup'] = True
 
-    # this uses the log_opts dictionary as parameters to logging.basicConfig()
-    logging.basicConfig(**log_opts)
-    return logging.getLogger("rich")
+        opts['handlers'] = [RichHandler(**rich_handler_opts)]
+
+    # this uses the opts dictionary as parameters to logging.basicConfig()
+    logging.basicConfig(**opts)
+
+    if log_file:
+        return None
+    else:
+        return logging.getLogger("rich")
 
 
 # @option('--quiet', '-q', is_flag=True, help=HELP['quiet'])
@@ -77,11 +87,12 @@ def setup_logger(level="", log_file=""):
         type=Choice(OPTS['package']['managers'][OS[0]]),
         help=HELP['pkg_managers'])
 @option('--pkg_groups', '-g', metavar='PKG_GROUP', multiple=True,
-        type=Choice(['default', 'gaming', 'media', 'devops']),
+        type=Choice(['default', 'gaming', 'gui', 'devops']),
         help=HELP['pkg_groups'])
 @option('--firewall', '-f', is_flag=True, help=HELP['firewall'])
 @option('--remote_host', '-r', metavar="IP_ADDR", multiple=True,
         help=HELP['remote_host'])
+@option('--version', is_flag=True, help=HELP['version'])
 def main(log_level: str = "",
          log_file: str = "",
          steps: str = "",
@@ -91,13 +102,20 @@ def main(log_level: str = "",
          pkg_managers: str = "",
          pkg_groups: str = "",
          firewall: bool = False,
-         remote_host: str = ""):
+         remote_host: str = "",
+         version: bool = False):
     """
     Uses config in the script repo in config/packages.yml and config/config.yml
-    If run with no options on Linux, it will install brew, pip3.10, apt,
-    flatpak, and snap packages. On mac, it only installs brew/pip3.10 packages.
+    If run with no options on Linux, it will install brew, pip3.11, apt,
+    flatpak, and snap packages. On mac, it only installs brew/pip3.11 packages.
     config loading tries to load: cli options and then .config/onboardme/*
     """
+
+    # only return the version if --version was passed in
+    if version:
+        print(f'\n🎉 v{get_version("onboardme")}\n')
+        return True
+
     # before we do anything, we need to make sure this OS is supported
     check_os_support()
 
@@ -108,33 +126,36 @@ def main(log_level: str = "",
     usr_pref = process_configs(overwrite, git_url, git_branch, pkg_managers,
                                pkg_groups, firewall, remote_host, steps)
 
-    log.debug(f"User passed in the following preferences:\n{usr_pref}\n",
-              extra={"markup": True})
+    if log:
+        log.debug(f"User passed in the following preferences:\n{usr_pref}\n")
+    else:
+        logging.debug(f"User passed in the following preferences:\n{usr_pref}")
 
     # actual heavy lifting of onboardme happens in these
     for step in usr_pref['steps'][OS[0]]:
 
         if step == 'dot_files':
-            from .dot_files import setup_dot_files
             # this creates a live git repo out of your home directory
             df_prefs = usr_pref['dot_files']
             setup_dot_files(OS, df_prefs['overwrite'],
                             df_prefs['git_url'], df_prefs['git_branch'])
 
         elif step == 'packages':
-            from .pkg_management import run_pkg_mngrs
             pkg_mngrs = usr_pref['package']['managers'][OS[0]]
             pkg_groups = usr_pref['package']['groups']
             run_pkg_mngrs(pkg_mngrs, pkg_groups)
 
         elif step in ['vim_setup', 'neovim_setup', 'font_setup']:
-            # import step from ide_setup.py in same directory
-            importlib.import_module('onboardme.ide_setup', package=f'.{step}')
+            # import step's function from ide_setup.py in same directory
+            import_module('onboardme.ide_setup', package=f'.{step}')
             func = getattr(ide_setup, step)
             func()
 
+        elif step == 'sudo_setup':
+            # if we're not running as root, kick off another process
+            setup_sudo()
+
     if 'firewall_setup' in steps:
-        from .firewall import configure_firewall
         configure_firewall(remote_host)
 
     print_manual_steps()
