@@ -73,7 +73,7 @@ def run_pkg_mngrs(pkg_mngrs=[], pkg_groups=[]):
         if any(check in pkg_groups for check in available_pkg_groups):
 
             pkg_emoji = pkg_mngr_dict['emoji']
-            msg = f'{pkg_emoji} [green][b]{pkg_mngr}[/b][/] app Installs'
+            msg = f'{pkg_emoji} [grn][b]{pkg_mngr}[/b][/grn] app management'
             print_header(msg)
 
             # commands for listing, installing, updating, upgrading, & cleanup
@@ -91,15 +91,13 @@ def run_pkg_mngrs(pkg_mngrs=[], pkg_groups=[]):
 
             # run the list command for the given package manager
             list_cmd = pkg_cmds['list']
-
-            # manually expanding, b/c there's not good way 2 do fstring via yml
-            if 'PWD' in list_cmd:
-                list_cmd = list_cmd.replace("PWD", PWD)
-
             list_pkgs = subproc([list_cmd], quiet=True)
 
-            # create list of installed packages to iterate on
-            installed_pkgs = list_pkgs.split()
+            if list_pkgs:
+                # create list of installed packages to iterate on
+                installed_pkgs = list_pkgs.split()
+            else:
+                installed_pkgs = []
 
             # iterate through package groups for a given package manager
             for pkg_group in pkg_groups:
